var indexSectionsWithContent =
{
  0: "0123456789:abcdefghiklmnoprstuwxy",
  1: "cs",
  2: "acdegilosuw",
  3: "acdefgilmsu",
  4: "s",
  5: "s",
  6: "abcefhiklmpstw",
  7: "123456789abcdfhiloprstuw"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "functions",
  3: "variables",
  4: "typedefs",
  5: "enumvalues",
  6: "groups",
  7: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Data Structures",
  2: "Functions",
  3: "Variables",
  4: "Typedefs",
  5: "Enumerator",
  6: "Modules",
  7: "Pages"
};

